@@ -9,9 +9,7 @@ export function SubmissionItemWait(props: {
 }): JSX.Element {
   return (
     <SubmissionItemContainer className={props.className}>
-      <ItemStatus
-        status={props.status}
-      />
+      <ItemStatus status={props.status} />
     </SubmissionItemContainer>
   );
 }
@@ -27,12 +25,10 @@ const SubmissionItemContainer = styled.li`
   line-height: 16px;
 `;
 
-
 const ItemStatus = styled(SubmissionItemWaitStatus)`
   height: 16px;
   flex-grow: 0;
   flex-shrink: 0;
 
-  width: 101px;
   margin-right: 8px;
 `;
